import { Actor } from '../../classes/actor.js';
import { Box } from '../../classes/box.js';
import { Scene } from '../../classes/scene.js';
import { VM } from '../../classes/vm.js';

const rootElement = document.getElementById('scene');
const rootBox = new Box('rootBox', rootElement).flex();
window.scene = new Scene('VM test', rootBox).withSequenceDiagram();

const testContractId = 'test-contract-id';
class TestContract extends Actor {
  constructor(vm, value) {
    super('TestContract');
    this.vm = vm;
    this.value = value;
  }

  hello(sender) {
    return `${sender.name} ${this.value}`;
  }
}

describe('VM', () => {
  let vm;
  let sender;
  let vmHandle;

  before(() => {
    vm = (window.vm = new VM());
    sender = new Actor('Sender');
    vm.addContract(testContractId, TestContract, 'world');
    vmHandle = vm.getHandle(sender);
  });

  it('Should exist', () => {
    should.exist(vm);
  });

  it('Call a contract method', () => {
    vmHandle.callContract(testContractId, 'hello').should.equal('Sender world');
  });
});
